# Shiny for Python Adaptive Filters

[![PyPI - Version](https://img.shields.io/pypi/v/shiny-adaptive-filter.svg)](https://pypi.org/project/shiny-adaptive-filter)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shiny-adaptive-filter.svg)](https://pypi.org/project/shiny-adaptive-filter)

-----

## Installation

```console
pip install git+https://github.com/chendaniely/pyshiny_adaptive_filter.git
```

```console
pip install shiny_adaptive_filter
```

## License

`pyshiny_adaptive_filter` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.


## Development Guide

Install Hatch

- <https://hatch.pypa.io/latest/install/>


```shell
brew install hatch
```

Need to install playwright browsers after new environment setup

```bash
playwright install
```
